@@ -12,9 +12,11 @@ op.mark <- list(
   # control for check_interactive() to return interactive() or TRUE
   mark.check_interactive = TRUE,
   mark.note.width = NULL,
+  mark.todos.force = FALSE,
 
   mark.days_in_month = 30,
   mark.days_in_year = 365,
   mark.weeks_inn_year = 52,
-  mark.default_tz = "UTC"
+  mark.default_tz = "UTC",
+  mark.na_list = na_list
 )
