@@ -1,4 +1,4 @@
-test_that("expand_by examples work", {
+test_that("expand_by() work", {
   x <- letters[c(3:2, 5, 9)]
   y <- letters[c(1:4, 8)]
 
@@ -23,9 +23,12 @@ test_that("expand_by examples work", {
   exp <- sort_names(c(c = "c", b = "b", e = "e", i = "i", a = NA, d = NA, h = NA))
   expect_equal(exp, res)
 
+  expect_error(expect_warning(expand_by(c(a = 1, a = 1), c(a = 1))))
+  expect_error(expect_warning(expand_by(c(a = 1), c(a = 1, a = 1))))
+  expect_error()
 })
 
-test_that("reindex examples work", {
+test_that("reindex() work", {
   iris1 <- head(iris, 5)
   iris1$index <- 1:5
   res <- reindex(iris1, "index", seq.int(2, 8, 2))
@@ -33,17 +36,21 @@ test_that("reindex examples work", {
   # row name attributes mode change
   expect_equal(res, exp, ignore_attr = TRUE)
 
-
   res <- reindex(iris1, "index", seq(2, 8, 2), expand = "both")
   exp <- iris1[seq(2:8), ]
   expect_equal(res, exp, ignore_attr = TRUE)
 
-
   #' # Using letters will show changes in rownames
   iris1$index <- letters[1:5]
   reindex(iris1, "index", letters[seq.int(2, 8, 2)])
 
   reindex(iris1, "index", seq(2, 8, 2))
   reindex(iris1, "index", seq(2, 8, 2), expand = "both")
+
+  expect_error(reindex(1), "data.frame")
+  expect_error(reindex(data.frame(a = 1), index = integer()), "new_index")
 })
 
+test_that("expand helpers work", {
+  expect_warning(unique_name_check(c(a = 1, a = 2)))
+})
