@@ -36,3 +36,10 @@ test_that("clean_na_coercion() works", {
     "^NAs introduced by coercion$"
   )
 })
+
+test_that("errors", {
+  txt <- "values to recode by were not properly set"
+  expect_error(recode_by(1, 1), txt)
+  expect_error(recode_only(1, 1), txt)
+})
+
